pub struct AspectRatio {
defer: bool,
align: Option<Align>,
}Fields
defer: boolalign: Option<Align>Implementations
Sourceimpl AspectRatio
impl AspectRatio
Sourcepub fn none() -> AspectRatio
pub fn none() -> AspectRatio
Produces the equivalent of preserveAspectRatio="none".
pub fn is_slice(&self) -> bool
pub fn compute(&self, vbox: &ViewBox, viewport: &Rect) -> Rect
Sourcepub fn viewport_to_viewbox_transform(
&self,
vbox: Option<ViewBox>,
viewport: &Rect,
) -> Result<Option<ValidTransform>, InvalidTransform>
pub fn viewport_to_viewbox_transform( &self, vbox: Option<ViewBox>, viewport: &Rect, ) -> Result<Option<ValidTransform>, InvalidTransform>
Computes the viewport to viewbox transformation.
Given a viewport, returns a transformation that will create a coordinate
space inside it. The (vbox.x0, vbox.y0) will be mapped to the viewport’s
upper-left corner, and the (vbox.x1, vbox.y1) will be mapped to the viewport’s
lower-right corner.
If the vbox or viewport are empty, returns Ok(None). Per the SVG spec, either
of those mean that the corresponding element should not be rendered.
If the vbox would create an invalid transform (say, a vbox with huge numbers that
leads to a near-zero scaling transform), returns an Err(()).